''' <summary>
''' implementiert IMessageFilter. Meldet sich selbstndig
''' beim Application-Objekt an bzw. auch wieder ab. 
''' </summary>
''' <remarks></remarks>
Public Class MessageEliminator
   Implements IMessageFilter

   Public Shared ReadOnly Singleton As New MessageEliminator

   Private Sub New()
   End Sub

   Private ReadOnly _SuppressedHandles As New List(Of IntPtr)

   Public Sub AddWindowHandle(ByVal Value As IntPtr)
      _SuppressedHandles.Add(Value)
      If _SuppressedHandles.Count = 1 Then
         'Diese Instanz eines IMessageFilters beim Application-Objekt anmelden
         Application.AddMessageFilter(Me)
      End If
   End Sub

   Public Sub RemoveWindowHandle(ByVal Value As IntPtr)
      _SuppressedHandles.Remove(Value)
      If _SuppressedHandles.Count = 0 Then
         'Filterung abstellen, wenn nicht mehr gebraucht
         Application.RemoveMessageFilter(Me)
      End If
   End Sub

   ''' <summary>
   ''' Dieser Schnittstellen-Member wird vom Application-Objekt 
   ''' aufgerufen, und zwar fr alle Messages aller Windows der 
   ''' gesamten Anwendung
   ''' </summary>
   ''' <returns>
   ''' True: Message wird unterdrckt
   ''' False: Message wird weiterverarbeitet
   ''' </returns>
   Public Function PreFilterMessage(ByRef m As Message) As Boolean _
         Implements IMessageFilter.PreFilterMessage
      Return _SuppressedHandles.Contains(m.HWnd)
   End Function

End Class 'MessageEliminator
